@@ -4,18 +4,19 @@ use warnings FATAL => 'all';
 
 sub next {
     my $self = shift;
-    # TODO: should @_ be replaced with splice @_, 0, 1?
-    $self->{next}->(@_) if defined $self->{next};
+
+    $self->{next}->(splice @_, 0, 1) if defined $self->{next};
 }
 
 sub error {
     my $self = shift;
-    # TODO: should @_ be replaced with splice @_, 0, 1?
-    $self->{error}->(@_) if defined $self->{error};
+
+    $self->{error}->(splice @_, 0, 1) if defined $self->{error};
 }
 
 sub complete {
     my $self = shift;
+
     $self->{complete}->() if defined $self->{complete};
 }
 
